package main

import (
	"bytes"
	"crypto/md5"
	"encoding/hex"
	"encoding/json"
	"fmt"
	"io"
	"net/http"
	"strconv"
	"time"
)

const (
	userName  = "" // 帐号用户名
	password = "" // 帐号密码
)

// 计算 sign 参数值
func getSign(timestamp int64) string {
	data := userName + strconv.FormatInt(timestamp, 10) + getMD5Hash(password)
	return getMD5Hash(data)
}

// 计算 MD5 值
func getMD5Hash(text string) string {
	hash := md5.Sum([]byte(text))
	return hex.EncodeToString(hash[:])
}

// 发送 HTTP 请求
func httpRequest(url string, data map[string]interface{}) string {
	jsonData, _ := json.Marshal(data)

	req, _ := http.NewRequest("POST", url, bytes.NewBuffer(jsonData))
	req.Header.Set("Content-Type", "application/json;charset=utf-8")
	req.Header.Set("Accept", "application/json")

	client := &http.Client{}
	resp, _ := client.Do(req)
	defer func() { _ = resp.Body.Close() }()

	body, _ := io.ReadAll(resp.Body)
	return string(body)
}

// 批量发送接口
func sendMass() {
	timestamp := time.Now().UnixNano() / int64(time.Millisecond) // 获取当前时间戳，精确到毫秒
	content := "【签名】短信内容"                                        // 短信内容
	phoneList := []string{"15011111111", "15022222222"}          // 发送手机号码列表

	// 定义请求数据
	data := map[string]interface{}{
		"userName":   userName,
		"content":   content,
		"phoneList": phoneList,
		"timestamp": timestamp,
		"sign":      getSign(timestamp),
	}
	// 发送 HTTP 请求
	result := httpRequest("http://{address:port}/sms/api/sendMessageMass", data)

	// 输出响应数据
	fmt.Println(result)
}

// 一对一发送接口
func sendOne() {
	timestamp := time.Now().UnixNano() / int64(time.Millisecond) // 获取当前时间戳，精确到毫秒

	messageList := []map[string]string{
		map[string]string{
			"phone":   "15011111111",
			"content": "【签名】短信内容",
		},
		map[string]string{
			"phone":   "15022222222",
			"content": "【签名】短信内容2",
		},
	}

	data := map[string]interface{}{
		"userName":     userName,
		"messageList": messageList,
		"timestamp":   timestamp,
		"sign":        getSign(timestamp),
	}

	result := httpRequest("http://{address:port}/sms/api/sendMessageOne", data)

	fmt.Println(result)
}

func main() {
	sendOne()
}
